**Example 1: 修改模板描述**

修改模板描述

Input: 

```
tccli monitor ModifyPrometheusTemp --cli-unfold-argument  \
    --TemplateId temp-xxx \
    --Template.Describe 一个模板
```

Output: 
```
{
    "Response": {
        "RequestId": "eac6b301-a322-493a-8e36-83b295459397"
    }
}
```

